@@ -34,7 +34,7 @@
 #include <gtk/gtktoolbar.h>
 #include <gsf/gsf-impl-utils.h>
 
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 
 typedef struct {
 	GtkToolItem	 base;
